All Classes and Interfaces
Class
Description
Add sparse matrices.
Approximate minimum degree ordering.
Sparse Cholesky.
Solves Ax=b where A is symmetric positive definite.
Common data structures.
Matrix in compressed-column or triplet form.
Output of Dulmage-Mendelsohn decomposition.
Output of numeric Cholesky, LU, or QR factorization
Output of symbolic Cholesky, LU, or QR analysis.
Convert a triplet form to compressed-column form.
Column counts for Cholesky and QR.
Cumulative sum.
Depth-first-search.
Dulmage-Mendelsohn decomposition.
Drop small entries from a sparse matrix.
Drop zeros from a sparse matrix.
Remove (and sum) duplicates.
Add an entry to a triplet matrix.
Nonzero pattern of kth row of Cholesky factor, L(k,1:k-1).
Find elimination tree.
Drop entries from a sparse matrix.
Sparse matrix times dense vector.
Apply Householder reflection.
Compute Householder reflection.
Interface for Dcs_fkeep.
Permute a vector, x = P'b.
Determine if j is a leaf of the skeleton matrix and find lowest common
ancestor (lca).
Load a sparse matrix from a file.
Solve a lower triangular system Lx=b.
Solve an upper triangular system L'x=b.
Sparse LU factorization.
Solve Ax=b using sparse LU factorization.
Maximum transveral (permutation for zero-free diagonal).
Sparse matrix multiply.
Sparse matrix 1-norm.
Permute a sparse matrix.
Invert a permutation vector.
Postorder a tree or forest.
Print a sparse matrix.
Permutes a vector, x=P*b.
Sparse QR factorization.
Solve a least-squares or underdetermined problem.
Random permutation.
Find nonzero pattern of x=L\b for sparse L and b.
Scatter a sparse vector.
Strongly-connected components.
Symbolic Cholesky ordering and analysis.
Sparse lower or upper triangular solve. x=G\b where G, x, and b are sparse,
and G upper/lower triangular.
Symbolic QR or LU ordering and analysis.
Symmetric permutation of a sparse matrix.
Depth-first-search of a tree.
Transpose a sparse matrix.
Sparse rank-1 Cholesky update/downate.
Solve an upper triangular system Ux=b.
Various utilities.
Solve a lower triangular system U'x=b.
Add sparse matrices.
Approximate minimum degree ordering.
Sparse Cholesky.
Solves Ax=b where A is symmetric positive definite.
Common data structures.
Complex matrix in compressed-column or triplet form.
Complex array.
Output of Dulmage-Mendelsohn decomposition.
Output of numeric Cholesky, LU, or QR factorization
Output of symbolic Cholesky, LU, or QR analysis.
Convert a triplet form to compressed-column form.
Column counts for Cholesky and QR.
Cumulative sum.
Depth-first-search.
Dulmage-Mendelsohn decomposition.
Drop small entries from a sparse matrix.
Drop zeros from a sparse matrix.
Remove (and sum) duplicates.
Add an entry to a triplet matrix.
Nonzero pattern of kth row of Cholesky factor, L(k,1:k-1).
Find elimination tree.
Drop entries from a sparse matrix.
Sparse matrix times dense vector.
Apply Householder reflection.
Compute Householder reflection.
Interface for Zcs_fkeep.
Permute a vector, x = P'b.
Determine if j is a leaf of the skeleton matrix and find lowest common
ancestor (lca).
Load a sparse matrix from a file.
Solve a lower triangular system Lx=b.
Solve an upper triangular system L'x=b.
Sparse LU factorization.
Solve Ax=b using sparse LU factorization.
Maximum transveral (permutation for zero-free diagonal).
Sparse matrix multiply.
Sparse matrix 1-norm.
Permute a sparse matrix.
Invert a permutation vector.
Postorder a tree or forest.
Print a sparse matrix.
Permutes a vector, x=P*b.
Sparse QR factorization.
Solve a least-squares or underdetermined problem.
Random permutation.
Find nonzero pattern of x=L\b for sparse L and b.
Scatter a sparse vector.
Strongly-connected components.
Symbolic Cholesky ordering and analysis.
Sparse lower or upper triangular solve. x=G\b where G, x, and b are sparse,
and G upper/lower triangular.
Symbolic QR or LU ordering and analysis.
Symmetric permutation of a sparse matrix.
Depth-first-search of a tree.
Transpose a sparse matrix.
Sparse rank-1 Cholesky update/downate.
Solve an upper triangular system Ux=b.
Various utilities.
Solve a lower triangular system U'x=b.
Add sparse matrices.
Approximate minimum degree ordering.
Sparse Cholesky.
Solves Ax=b where A is symmetric positive definite.
Common data structures.
Matrix in compressed-column or triplet form.
Output of Sulmage-Mendelsohn decomposition.
Output of numeric Cholesky, LU, or QR factorization
Output of symbolic Cholesky, LU, or QR analysis.
Convert a triplet form to compressed-column form.
Column counts for Cholesky and QR.
Cumulative sum.
Support routines for Scs_demo*.java
A structure for a demo problem.
Read a matrix from a file and perform basic matrix operations.
Read a matrix from a file and solve a linear system.
Read a matrix, solve a linear system, update/downdate.
Septh-first-search.
Sulmage-Mendelsohn decomposition.
Srop small entries from a sparse matrix.
Srop zeros from a sparse matrix.
Remove (and sum) duplicates.
Add an entry to a triplet matrix.
Nonzero pattern of kth row of Cholesky factor, L(k,1:k-1).
Find elimination tree.
Srop entries from a sparse matrix.
Sparse matrix times dense vector.
Apply Householder reflection.
Compute Householder reflection.
Interface for Scs_fkeep.
Permute a vector, x = P'b.
Setermine if j is a leaf of the skeleton matrix and find lowest common
ancestor (lca).
Load a sparse matrix from a file.
Solve a lower triangular system Lx=b.
Solve an upper triangular system L'x=b.
Sparse LU factorization.
Solve Ax=b using sparse LU factorization.
Maximum transveral (permutation for zero-free diagonal).
Sparse matrix multiply.
Sparse matrix 1-norm.
Permute a sparse matrix.
Invert a permutation vector.
Postorder a tree or forest.
Print a sparse matrix.
Permutes a vector, x=P*b.
Sparse QR factorization.
Solve a least-squares or underdetermined problem.
Random permutation.
Find nonzero pattern of x=L\b for sparse L and b.
Scatter a sparse vector.
Strongly-connected components.
Symbolic Cholesky ordering and analysis.
Sparse lower or upper triangular solve. x=G\b where G, x, and b are sparse,
and G upper/lower triangular.
Symbolic QR or LU ordering and analysis.
Symmetric permutation of a sparse matrix.
Septh-first-search of a tree.
Transpose a sparse matrix.
Sparse rank-1 Cholesky update/downate.
Solve an upper triangular system Ux=b.
Various utilities.
Solve a lower triangular system U'x=b.